@@ -1,6 +1,7 @@
 """
 Sentinel api functions as a mixin
 """
+from jaseci.api.interface import interface
 from jaseci.utils.id_list import id_list
 from jaseci.actor.sentinel import sentinel
 from jaseci.utils.utils import b64decode_str
@@ -16,9 +17,11 @@ class sentinel_api():
         self.active_snt_id = None
         self.sentinel_ids = id_list(self)
 
-    def api_sentinel_register(self, name: str, code: str = '',
-                              encoded: bool = False, auto_run: str = 'init',
-                              ctx: dict = {}, set_active: bool = True):
+    @interface.private_api(cli_args=['code'])
+    def sentinel_register(self, name: str = 'default', code: str = '',
+                          encoded: bool = False, auto_run: str = 'init',
+                          auto_gen_graph: bool = True, ctx: dict = {},
+                          set_active: bool = True):
         """
         Create blank or code loaded sentinel and return object
         Auto_run is the walker to execute on register (assumes active graph
@@ -29,7 +32,8 @@ class sentinel_api():
         if(not snt):
             snt = sentinel(m_id=self._m_id, h=self._h, name=name)
             self.sentinel_ids.add_obj(snt)
-            new_gph = self.api_graph_create(set_active=True)
+            if(auto_gen_graph):
+                new_gph = self.graph_create(set_active=True)
         if(code):
             if (encoded):
                 code = b64decode_str(code)
@@ -38,17 +42,18 @@ class sentinel_api():
                 return {'response': 'Error in jac code', 'errors': snt.errors}
         if(snt.walker_ids.has_obj_by_name(auto_run) and self.active_gph_id):
             nd = self._h.get_obj(self._m_id, uuid.UUID(self.active_gph_id))
-            self.api_walker_run(name=auto_run, nd=nd, ctx=ctx,
-                                snt=snt)
+            self.walker_run(name=auto_run, nd=nd, ctx=ctx,
+                            snt=snt)
         if(set_active):
-            self.api_sentinel_active_set(snt)
+            self.sentinel_active_set(snt)
         self.extract_snt_aliases(snt)
         if(new_gph):
             return [snt.serialize(), new_gph]
         return [snt.serialize()]
 
-    def api_sentinel_pull(self, set_active: bool = True,
-                          on_demand: bool = True):
+    @interface.private_api()
+    def sentinel_pull(self, set_active: bool = True,
+                      on_demand: bool = True):
         """
         Copies global sentinel to local master
         """
@@ -66,12 +71,13 @@ class sentinel_api():
             return {'response': f'{snt} already active!',
                     'success': True}
         if(set_active):
-            self.api_sentinel_active_set(snt)
-        return self.api_sentinel_set(code=g_snt.code_ir, snt=snt,
-                                     mode='ir')
+            self.sentinel_active_set(snt)
+        return self.sentinel_set(code=g_snt.code_ir, snt=snt,
+                                 mode='ir')
 
-    def api_sentinel_get(self, snt: sentinel = None,
-                         mode: str = 'default', detailed: bool = False):
+    @interface.private_api()
+    def sentinel_get(self, snt: sentinel = None,
+                     mode: str = 'default', detailed: bool = False):
         """
         Get a sentinel rendered with specific mode
         Valid modes: {default, code, ir, }
@@ -83,8 +89,9 @@ class sentinel_api():
         else:
             return snt.serialize(detailed=detailed)
 
-    def api_sentinel_set(self, code: str, encoded: bool = False,
-                         snt: sentinel = None, mode: str = 'default'):
+    @interface.private_api(cli_args=['code'])
+    def sentinel_set(self, code: str, encoded: bool = False,
+                     snt: sentinel = None, mode: str = 'default'):
         """
         Set code/ir for a sentinel, only replaces walkers/archs in sentinel
         Valid modes: {code, ir, }
@@ -110,7 +117,8 @@ class sentinel_api():
                     'success': False,
                     'errors': snt.errors+snt.runtime_errors}
 
-    def api_sentinel_list(self, detailed: bool = False):
+    @interface.private_api()
+    def sentinel_list(self, detailed: bool = False):
         """
         Provide complete list of all sentinel objects
         """
@@ -119,23 +127,34 @@ class sentinel_api():
             snts.append(i.serialize(detailed=detailed))
         return snts
 
-    def api_sentinel_active_set(self, snt: sentinel):
+    @interface.private_api()
+    def sentinel_test(self, snt: sentinel = None,
+                      detailed: bool = False):
+        """
+        Run battery of test cases within sentinel and provide result
+        """
+        return snt.run_tests(detailed=detailed)
+
+    @interface.private_api(cli_args=['snt'])
+    def sentinel_active_set(self, snt: sentinel):
         """
         Sets the default sentinel master should use
         """
         self.active_snt_id = snt.jid
-        self.api_alias_register('active:sentinel', snt.jid)
+        self.alias_register('active:sentinel', snt.jid)
         return [f'Sentinel {snt.id} set as default']
 
-    def api_sentinel_active_unset(self):
+    @interface.private_api()
+    def sentinel_active_unset(self):
         """
         Unsets the default sentinel master should use
         """
         self.active_snt_id = None
-        self.api_alias_delete('active:sentinel')
+        self.alias_delete('active:sentinel')
         return ['Default sentinel unset']
 
-    def api_sentinel_active_global(self, detailed: bool = False):
+    @interface.private_api()
+    def sentinel_active_global(self, detailed: bool = False):
         """
         Sets the default master sentinel to the global sentinel
         Exclusive OR with pull strategy
@@ -146,14 +165,15 @@ class sentinel_api():
             ret['response'] = 'No global sentinel is available!'
         else:
             self.active_snt_id = "global"  # Resolved in interface
-            self.api_alias_register('active:sentinel', glob_id)
+            self.alias_register('active:sentinel', glob_id)
             ret['sentinel'] = self._h.get_obj(
                 self._m_id, uuid.UUID(glob_id)).serialize(detailed=detailed)
             ret['success'] = True
             ret['response'] = f'Global sentinel {glob_id} set as default'
         return ret
 
-    def api_sentinel_active_get(self, detailed: bool = False):
+    @interface.private_api()
+    def sentinel_active_get(self, detailed: bool = False):
         """
         Returns the default sentinel master is using
         """
@@ -167,16 +187,21 @@ class sentinel_api():
                 self._m_id, uuid.UUID(id))
             return default.serialize(detailed=detailed)
 
-    def api_sentinel_delete(self, snt: sentinel):
+    @interface.private_api(cli_args=['snt'])
+    def sentinel_delete(self, snt: sentinel):
         """
         Permanently delete sentinel with given id
         """
         self.remove_snt_aliases(snt)
         if(self.active_snt_id == snt.jid):
-            self.api_sentinel_active_unset()
+            self.sentinel_active_unset()
         self.sentinel_ids.destroy_obj(snt)
         return [f'Sentinel {snt.id} successfully deleted']
 
+    def active_snt(self):
+        return self._h.get_obj(
+            self._m_id, uuid.UUID(self.active_snt_id))
+
     def destroy(self):
         """
         Destroys self from memory and persistent storage
