@@ -145,14 +145,20 @@ class architype_interp(interp):
             else:
                 edge_obj = edge(m_id=self._m_id, h=self._h,
                                 kind='edge', name='generic')
-            lhs_node = node_objs.get(op['lhs_node_id'], None)
+
+            lhs_node_id = op.pop('lhs_node_id')
+            rhs_node_id = op.pop('rhs_node_id')
+            op.pop('op')
+            op.pop('is_directional')
+            edge_obj.set_context(op)
+            lhs_node = node_objs.get(lhs_node_id, None)
             if(lhs_node is None):
                 del nodes_def
                 del node_objs
                 del edge_objs
                 self.rt_error('Invalid from node for edge')
                 return None
-            rhs_node = node_objs.get(op['rhs_node_id'], None)
+            rhs_node = node_objs.get(rhs_node_id, None)
             if(rhs_node is None):
                 del nodes_def
                 del node_objs
@@ -243,7 +249,7 @@ class architype_interp(interp):
             lhs_id = self.run_dot_id(kid[0])
             kid = kid[1:]
             if (len(kid) == 0 or kid[0].token_text() != '='):
-                # If there is rhs, treat it as a boolean value of True
+                # If there is no rhs, treat it as a boolean value of True
                 # e.g. [is_active, color=red] sets the attributes
                 # is_active as True and color as "red"
                 rhs_id = True
