@@ -83,6 +83,14 @@ class machine_state():
             self.rt_error(f"Builtin action not found - {func_name}", jac_ast)
         return func_name
 
+    def jac_exception(self, e: Exception, jac_ast):
+        return {'type': type(e).__name__,
+                'mod': jac_ast.mod_name,
+                'msg': str(e),
+                'args': e.args,
+                'line': jac_ast.line,
+                'col': jac_ast.column}
+
     def rt_log_str(self, msg, jac_ast=None):
         """Generates string for screen output"""
         name = self.name if hasattr(self, 'name') else 'blank'
