@@ -157,6 +157,44 @@ dot_edge_with_attrs = \
     }
     """
 
+dot_edge_with_attrs_vars = \
+    """
+    node test_node {
+        has name;
+    }
+    edge special {
+        has name;
+    }
+    graph test_graph {
+        has anchor graph_root;
+        graph G {
+            graph_root [node=test_node, name=root]
+            node_1 [node=test_node, name=node_1]
+            node_2 [node=test_node, name=node_2]
+            graph_root -> node_1 [edge=special, name=edge_1]
+            graph_root -> node_2
+        }
+    }
+    walker init {
+        has nodes;
+        with entry {
+            nodes = [];
+        }
+        root {
+            spawn here --> graph::test_graph;
+            take --> node::test_node;
+        }
+        test_node {
+            for i in -[special]->.edge {
+                std.out(i.name);
+            }
+            for i in -[special(name == "edge_1")]-> {
+                std.out(i.name);
+            }
+        }
+    }
+    """
+
 dot_graph = \
     """
     node year {
